CssLike
=======

This is a parser for CSS-like stylesheets.

 * Supports CSS-style rulesets and properties.
 * Supports directives to use application-specific features.
 * Can be serialized to avoid having to re-parse styles when the stylesheet file
   has not been modified since the last time parsed.
 * Can parse from string or directly from file.
 * Multiple files/strings can be parsed into a single stylesheet object.
 * All rules are evaluated, meaning that properties found later in the stylesheet
   will override previous matching rules.
 * Multiple rules can be passed to select, making the parser flexible without
   putting constraint on how rules are composed.
 * Selectors are all considered at the same level, thus you can't create rules
   that reference parent or children unless part of your application-specific
   use.


## Usage

Create a stylesheet and parse files and strings:

    $style = new Stylesheet();
    $style->parse("theme.style");
    $style->parseString("style { property: value; }");

You can also pass a filename to the constructor:

    $style = new Stylesheet("theme.style");

Get directives using the `getDirective(name)` and `getAllDirectives()` methods.
Both functions return arrays even if only a single directive matches.

    $style->parseString("color(red,#ff0000);");
    $directives = $style->getDirective("color");

The result would be:

    [
      [ 'color', [ 'red', '#ff0000' ]]
    ]

To match rules, use `select(rule, ...)`:

    $logformat = [
        'debug' => $style->select("log","log.debug","log:good"),
        'info'  => $style->select("log","log.info","log:good"),
        'warn'  => $style->select("log","log.warning","log:bad"),
        'error' => $style->select("log","log.error","log:bad")
    ];

In this case, the following would be returned:

    [
      'debug' => [ 'style'=>'bold', 'color'=>'green' ],
      'info'  => [ 'style'=>'bold', 'color'=>'green' ],
      'warn'  => [ 'style'=>'bold' ],
      'error' => [ 'style'=>'bold', 'color'=>'red' ],
    ]

## Definitions

### Directives

Directives consist of a name and a number of parameters, and can be likened with
functions. They can be used to define variables or add custom functionality.

    foo('answer',42);
    bar();
    @baz(1,2,3);
    #bin(hello world);

### Rulesets

Rulesets combine properties and values based on a selector.

    log {
        style: bold;
    }
    log.error { color: red; }
    log:good
    {
        color: green;
    }

### Comments

Comments are supported as blocks (`/* .. */`) and not as single lines (`//`):

    /*  This is a comment! Comments can
        span multiple lines */
