<?php

namespace NoccyLabs\CssLike;

/**
 * 
 * 
 */
class Ruleset
{
    /** @var Selector The selector that this ruleset should be applied to */
    protected $selector;
    /** @var Property[] The properties */
    protected $properties = [];

    /**
     * Create a new ruleset
     *
     * @param Selector $selector The selector for this ruleset
     * @param Property[] $properties The propertie
     */
    public function __construct(Selector $selector, array $properties)
    {
        $this->selector = $selector;
        $this->properties = $properties;
    }

    /**
     * Test if any of the selectors match this ruleset.
     *
     * @param array $match
     * @return bool
     */
    public function matchSelectors(array $match)
    {
        foreach ($match as $string) {
            if ($this->selector->matches($string)) return true;
        }
        return false;
    }

    /**
     * Get all properties in the ruleset as an array
     *
     * @return array
     */
    public function getPropertiesArray()
    {
        $props = [];
        foreach ($this->properties as $property) {
            $props[$property->getName()] = $property->getValue();
        }
        return $props;
    }

}

