<?php

namespace NoccyLabs\CssLike;

class StringParser
{
    protected $string;

    protected $tokens;

    protected $offs = 0;

    /**
     * Create a new parser, using the specified characters as token separators.
     *
     * @param string $string The string to parse
     * @param string $tokens Characters to use for tokenizing
     */
    public function __construct($string, $tokens)
    {
        $this->string = $string;
        $this->tokens = $tokens;
    }

    /**
     * Get the next token. Returns null if none. The next separating token
     * will be assigned byref to &$matched_token
     *
     * @param string &$matched_token The next token found
     * @return string|null The next chunk
     */
    public function getNext(&$matched_token)
    {
        $fm = null;
        $fp = null;
        for ($t = 0; $t < strlen($this->tokens); $t++) {
            $tm = $this->tokens[$t];
            $tp = @strpos($this->string, $tm, $this->offs);
            if ($tp === false) continue;
            if (($fp === null) || ($fp > $tp)) {
                $fp = $tp;
                $fm = $tm;
            }
        }
        if ($fp===null) {
            if ($this->offs < strlen($this->string)) {
                $ret = substr($this->string, $this->offs);
                $fp = strlen($this->string);
            } else {
                $ret = null;
            }
        } else {
            $ret = substr($this->string, $this->offs, $fp-$this->offs);
        }

        $this->offs = $fp + 1;
        $matched_token = $fm;

        return $ret;
    }

}

