<?php

use NoccyLabs\CssLike\Stylesheet;


class StylesheetTest extends \PhpUnit\Framework\TestCase
{

    public function setup()
    {
        $this->style = new Stylesheet();
        $this->style->parse(__DIR__."/../styles/test.style");
    }

    public function testDirectives()
    {
        $directives = $this->style->getAllDirectives();

        $this->assertCount(4, $directives);
    }

    public function testDirectiveValuesA()
    {
        $directive = $this->style->getDirectives("directive_a");
        $this->assertCount(1, $directive);
        $this->assertEquals([], $directive[0]);
    }

    public function testDirectiveValuesB()
    {
        $directive = $this->style->getDirectives("directive_b");
        $this->assertCount(1, $directive);
        $this->assertEquals(['foo'], $directive[0]);
    }

    public function testDirectiveValuesC()
    {
        $directive = $this->style->getDirectives("directive_c");
        $this->assertCount(1, $directive);
        $this->assertEquals(['foo','bar baz'], $directive[0]);
    }

    public function testDirectiveValuesD()
    {
        $directive = $this->style->getDirectives("directive_d");
        $this->assertCount(1, $directive);
        $this->assertEquals([42], $directive[0]);
    }

    public function testSelectFoo()
    {
        $props = $this->style->select("foo");
        
        $this->assertCount(1, $props);
        $this->assertEquals(['prop_a'=>'yes'], $props);
    }

    public function testSelectFooAwesome()
    {
        $props = $this->style->select("foo", "foo.awesome");
        
        $this->assertCount(2, $props);
        $this->assertEquals(['prop_a'=>'yes', 'prop_d'=>'present'], $props);
    }

    public function testSelectBar()
    {
        $props = $this->style->select("bar");
        
        $this->assertCount(3, $props);
        $this->assertEquals(['prop_a'=>'yes', 'prop_b'=>'true', 'prop_c'=>'hello world'], $props);
    }

}
